# hpass

Hello Password

**Why?** Because I can't believe the current password management software. In addition, the fact that the data file cannot be exported bothers me.

## Installation

As usual, the easiest way is with pip:

```powershell
$ pip install hpass
```

Alternatively you can [download](https://pypi.org/project/hpass/#files) the `hpass-x.x.x.tar.gz` installation file:

```powershell
$ pip install hpass-x.x.x.tar.gz
```

Pip will install dependencies *([colorama](https://pypi.org/project/colorama/) and [PrettyTable](https://pypi.org/project/PrettyTable/))* for you. Alternatively you can clone the repository:

```powershell
$ git clone https://github.com/hekaiyou/hpass.git --recursive
$ cd hpass
$ python setup.py install
```

## Usage
